package org.jconfig.items;

import javax.xml.parsers.*;
import org.xml.sax.*;
import org.xml.sax.helpers.*;

/**
 *  <p>package:    org.jconfig.items</p>
 *  <p>file:       TreeItemHandler.java</p>
 * $Id: TreeItemHandler.java,v 1.3 2004/04/19 08:12:45 tgl Exp $
 *
 *  <p>Copyright 2003 Thomas Gleixner <tglx@linutronix.de></p>
 *
 * <p>This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 2 as
 *  published by the Free Software Foundation.</p>
 * </p>
 *
 * Change Log:
 * </p>
 * <ul>
 * <li> 1.0 First implementation
 * </ul>
 * <p>
 *	XML to item parser
 * </p>
 *
 * @author Thomas Gleixner <tglx@linutronix.de>
 * @version 1.0
 */
public class TreeItemHandler extends org.xml.sax.helpers.DefaultHandler {

    TreeItem    items, current;
    int         level = 0;
    boolean     expandarrays;
   
    /** Creates a new instance of ItemHandler */
    public TreeItemHandler(TreeItem it, boolean expand) {
        items = it;
        current = items;
        expandarrays = expand;
    }
    
    private String Decode (String content) {
        try {
            return java.net.URLDecoder.decode(content, "UTF-8");
        } catch (Exception e) { 
            System.out.println(e);
            System.out.println(content);
        }
        return content;
    }
    
    public void startElement(String uri, String localName, String qName, Attributes attributes) {
        current = current.AddItem (new TreeItem (qName, current));
        current.SetContent("");
        level++;
        for (int i = 0; i < attributes.getLength(); i++)
            current.AddAttr(new ItemAttr(Decode(attributes.getQName(i)), Decode(attributes.getValue(i))));
    }

    public void endElement(String uri, String localName, String qName) {
        if (expandarrays) {
            // Check, if this is an array
            int size, offset;
            try { size = Integer.parseInt(current.GetAttrValue("arraysize"), 10); } 
            catch (Exception e) { size = 0; }
            try { offset = Integer.parseInt(current.GetAttrValue("offset"), 10); } 
            catch (Exception e) { offset = 0; }
            if (size > 0) {
                TreeItem parent = current.GetParent();
                for (int i = 0; i < size; i++)
                    parent.AddItem(new TreeItem (current, offset + i));
                parent.RemoveItem(current);
                current = parent.GetItem(size -1);
            }
        }    
        
        level--;
        if (level > 0)
            current = current.GetParent();
    }

    public void processingInstruction(String target, String data) {
        System.out.println("processing instruction: " + target);
    }

    public void characters(char[] ch, int start, int length) {
            String c = Decode(new String(ch, start, length).trim());
            current.SetContent (current.GetContent() + c);
    }
    
    public void warning(SAXParseException e) {
        System.out.println("Warning:" + (e.getMessage () != null
                    ? e.getMessage ()
                    : e.getClass ().getName ()));
    }
    
    public void error(SAXParseException e) {
        System.out.println("Error:" + (e.getMessage () != null
                    ? e.getMessage ()
                    : e.getClass ().getName ()));
    }    
}
