package org.jvisu.base;

import java.awt.*;
import java.io.*;
import java.net.*;
import java.beans.*;
import javax.swing.*;
import org.jvisu.comm.*;
import org.jvisu.comm.var.*;

/** Visual component to display a image and reload it on variable change
 *
 *  <p>Copyright 2003 Thomas Gleixner <tglx@linutronix.de></p>
 *
 *  <p>This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 2 as
 *  published by the Free Software Foundation. See file LICENCE in this
 *  directory</p>
 * <p>
 *
 * <p>
 * Change Log:
 * </p>
 * <ul>
 * <li> 1.0 First implementation
 * </ul>
 * <p>
 * </p>
 *  The purpose of JVDigits is to display a rectangular shape, which contains
 *  the numerical representation of a variable. The representation can be 
 *  customized by various methods.
 *  The components has a builtin min/max compare function, which can be custumized by 
 *  absolute values or variable values, which are retrieved from the communication server
 *
 * @author Thomas Gleixner <tglx@linutronix.de>
 * @version 1.0
 */
public class JVImage extends JVBean implements JVVarListener {

    /** the background image file address. The address is
     *  relative to base, if base is != null. Else it is
     *  treated as an absolute reference.
     */
    private String                  imageFile;
    /** scaled background Image */
    protected Image                 image;
 
    /** Create a new instance ofJVHexByte
     */
    public JVImage() {
        this.setDesignsize(new Dimension (100,30));
        addCommVar (new JVVarCfg(null, updaterate, JVVar.T_INT, 0, 0));
    }

    /** Property change listener
     *  @param evt the property event
     */
    public void propertyChange(PropertyChangeEvent evt) {
        super.propertyChange(evt);
        String key = evt.getPropertyName();
        
        /* These are local events */
        if (evt.getSource() == this) {
            if (key.equals("base") || 
                key.equals("imageFile") ||
                key.equals("preferredSize") ||
                key.equals("varchanged")
                ) {
                readImageFile();
            }
        }
    }

    /** Try to read the image file */
    private void readImageFile() {
        try {
            URL url;
            if (base == null)
                url = new URL(imageFile);
            else
                url = new URL(new URL(base), imageFile);
            Dimension size = getPreferredSize();
            image= javax.imageio.ImageIO.read(url).getScaledInstance(size.width, size.height, Image.SCALE_DEFAULT);
        } catch (Exception e) {
            image = null;
        }
        repaint();
    }
    
    /** Subclasses have to implement a start function
     */
    public void StartUp() {
    }

    /** Subclasses have to implement a stop function
     */
    public void Shutdown() {
    }

    /** Variable has changed */
    public void VarChanged (JVVar var) {
        firePropertyChange("varchanged", false, true);
    }

    /** Get the symbol of the communication variable
     * @return the variable symbol of this component
     */
    public String getCommVar() {
        return getCommVarSymbol(0);
    }

    /** Set the symbol of the communication variable
     * @param symbol the variable symbol of this component
     */
    public void setCommVar(String symbol) {
        setCommVarSymbol(0, symbol);
    }

    /** Get the address of the background image file
     * @return background image file address
     */
    public String getImageFile() {
        return this.imageFile;
    }
    
    /** Set the background image file address
     * @param imgfile new background image file address
     */
    public void setImageFile(String imgfile) {
        String old = imageFile;
        imageFile = imgfile;
        firePropertyChange("imageFile", old, imageFile);
    }

    /** VisuDigits specific paint function.
     *  Check, if a min/max check is given<br>
     *  If yes, check, if value is inside the tresholds.<br>
     *  If inside use backcolor, else use alarmcolor
     * @param g Graphics context
     */
    public void paintComponent (Graphics g) {
        if (image == null)
            super.paintComponent(g);
        else
            g.drawImage(image, 0, 0, this);
    }
}
