/*
 * JVPanel.java
 *
 * Created on 15. September 2003, 08:11
 */

package org.jvisu.base;

import java.awt.*;
import java.beans.*;
import javax.swing.*;
import org.jvisu.panel.*;

/**
 *  <p>package:    JVisu</p>
 *  <p>file:       JVLabel.java</p>
 * $Id: JVLabel.java,v 1.6 2004/04/19 08:20:55 tgl Exp $
 *
 *  <p>Copyright 2003 Thomas Gleixner <tglx@linutronix.de></p>
 *
 * <p>This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 2 as
 *  published by the Free Software Foundation.</p>
 * </p>
 *
 * Change Log:
 * </p>
 * <ul>g
 * <li> 1.0 First implementation
 * </ul>
 * <p>
 * A simple label
 * </p>
 *
 * @author Thomas Gleixner <tglx@linutronix.de>
 * @version 1.0
 */
public class JVLabel extends javax.swing.JLabel implements JVBaseMembers,
                                    PropertyChangeListener {

    /** Position of this component */
    protected Point                 designpos;    
    /** Size of this component */
    protected Dimension             designsize;
    /** Zoom support */
    protected double                zoomfactor = 1.0;
    /** The fontsize designed for this component */
    protected int                   fontsize;
    /** The designmodel for this component */
    private String                  designmodel;
    
    /** Creates a new instance of JVLabel */
    public JVLabel() {
        designpos = new Point(0,0);
        designmodel = getClass().getName();
        designsize = new Dimension(50,20);
        fontsize = getFont().getSize();
        setText("Label");
        addPropertyChangeListener(this);
    }

    /** Property change listener
     *  @param evt the property event
     */
    public void propertyChange(PropertyChangeEvent evt) {
        if (evt.getSource() == this) {
            String key = evt.getPropertyName();
            if (key.equals("designsize") || key.equals("zoomfactor")) {
                recalcSize();
            }
        } 
    }
    
    /** Called by the parent component, when the component is
     *  added.
     *  Startup component
     */
    public void addNotify() {
        /* Let the superclass do its magic */
        super.addNotify();
        firePropertyChange("designpos", null, designpos);
    }
    
    /** Getter for property designpos.
     * @return Value of property designpos.
     */
    public Point getDesignpos() {
        return designpos;
    }
    
    /** Setter for property designpos.
     * @param newpos new position
     */
    public void setDesignpos(Point newpos) {
        Point oldpos = new Point(designpos);
        designpos.setLocation(newpos);
        firePropertyChange("designpos", oldpos, newpos);
    }
    
    /** get the designmodel for this component 
     * @return designmodel
     */
    public String getDesignModel() {
        return designmodel;
    }
    
    /** set the designmodel for this component 
     * @param model designmodel
     */
    public void setDesignModel(String model) {
        designmodel = model;
    }

    /** Get the ability of this component to have subcomponents
     * @return true, if subcomponents are allowed
     */
    public boolean isContainer() {
        return false;
    }
    
    /** Return the design size of this component
     * @return design size
     */
    public Dimension getDesignsize() {
        return designsize;
    }

    /** Set the design size of this component.
     * @param newpos new designsize
     */
    public void setDesignsize(Dimension newsize) {
        Dimension oldsize = new Dimension (designsize);
        designsize.setSize(newsize);
        firePropertyChange("designsize", oldsize, newsize);
    }

    /** Get the zoom factor of this component
     * @return zoomfactor for this component
     */
    public double getZoomfactor() {
        return zoomfactor;
    }

    /** Set the zoom factor of this component
     * @param zoom new zoomfactor for this component
     */
    public void setZoomfactor(double zoom) {
        double oldzoom = zoomfactor;
        zoomfactor = zoom;
        firePropertyChange("zoomfactor", oldzoom, zoom);
    }
    
    /** Recalc the size depending on zoom factor and designsize 
     */
    private void recalcSize() {
        Dimension d = new Dimension(designsize);
        d.setSize(zoomfactor * d.getWidth(), zoomfactor * d.getHeight());
        this.setPreferredSize(d);
        Font font = super.getFont();
        super.setFont(new Font(font.getName(), font.getStyle(), 
            (int)(zoomfactor * (double) fontsize)));
    }
    
    /** Set the font 
     *  @param font the new font
     */
    public void setDesignFont(Font font) {
        fontsize = font.getSize();
        super.setFont(new Font(font.getName(), font.getStyle(), 
            (int)(zoomfactor * (double) fontsize)));
    }

    /** Get the font 
     *  @param font the new font
     */
    public Font getDesignFont() {
        Font font = super.getFont();
        return new Font(font.getName(), font.getStyle(), fontsize);
    }
    
}
