/*
 * A password dialog box.
 *
 * Derived from PasswordDialog written by
 * Copyright (C) 2001, 2002 Stephen Ostermiller 
 * http://ostermiller.org/contact.pl?regarding=Java+Utilities
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 */

package org.jvisu.util;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.ResourceBundle;
import java.util.Locale;

/** A modal dialog that asks the user for a password.
 *
 *  <p>package:  org.jvisu.util</p>
 *  <p>file:    JVPasswordDlg.java</p>
 *  <p>$Id: JVPasswordDlg.java,v 1.2 2004/04/19 08:20:55 tgl Exp $ </p>
 *  <p>Copyright 2003 Thomas Gleixner <tglx@linutronix.de></p>
 *
 *  <p>This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 2 as
 *  published by the Free Software Foundation. See file LICENCE in this
 *  directory</p>
 *  
 *  <p>Change Log:</p>
 *  <ul>
 *  <li> 1.0 Initial inmplimentation </li>
 *  </ul>
 *  <p>
 *	Password dialog
 *  </p>
 *
 * @author Thomas Gleixner <tglx@linutronix.de>
 * @version 1.0 
*/
public class JVPasswordDlg extends JDialog {

    /** Where the password is typed. */
    protected JPasswordField pass;
    /** The OK button. */
    protected JButton okButton;
    /** The cancel button. */
    protected JButton cancelButton;
    /** label for the field in which the password is typed. */
    protected JLabel passLabel;
    /** OK was pressed */
    private boolean pressed_OK;

    /** Get the password that was entered into the dialog before
     *  the dialog was closed.
     *  @return the password from the password field.
     */
    public String getPass(){
        return new String(pass.getPassword());
    }

    /** Create this dialog with the given parent
     * @param parent window from which this dialog is launched
     */
    public JVPasswordDlg(Frame parent) {
        this(parent, null);
    }

    /** Create this dialog with the given parent and title.
     * @param parent window from which this dialog is launched
     * @param title the title for the dialog box window
     */
    public JVPasswordDlg(Frame parent, String title) {
        super(parent, title, true);
        if (title==null)
            setTitle("Password");
        if (parent != null)
            setLocationRelativeTo(parent);
    }

    /** Called by constructors to initialize the dialog.
     */
    protected void dialogInit(){

        pass = new JPasswordField("", 10);
        okButton = new JButton("OK");
        cancelButton = new JButton("Cancel");
        passLabel = new JLabel("Enter password");

        super.dialogInit();

        KeyListener keyListener = (new KeyAdapter() {
            public void keyPressed(KeyEvent e){
                if (e.getKeyCode() == KeyEvent.VK_ESCAPE ||
                        (e.getSource() == cancelButton
                        && e.getKeyCode() == KeyEvent.VK_ENTER)){
                    pressed_OK = false;
                    JVPasswordDlg.this.hide();
                }
                if (e.getSource() == okButton &&
                        e.getKeyCode() == KeyEvent.VK_ENTER){
                    pressed_OK = true;
                    JVPasswordDlg.this.hide();
                }
            }
        });
        addKeyListener(keyListener);

        ActionListener actionListener = new ActionListener() {
            public void actionPerformed(ActionEvent e){
                Object source = e.getSource();
                pressed_OK = (source == pass || source == okButton);
                JVPasswordDlg.this.hide();
            }
        };

        GridBagLayout gridbag = new GridBagLayout();
        GridBagConstraints c = new GridBagConstraints();
        c.insets.top = 5;
        c.insets.bottom = 5;
        JPanel pane = new JPanel(gridbag);
        pane.setBorder(BorderFactory.createEmptyBorder(10, 20, 5, 20));
        JLabel label;

        c.anchor = GridBagConstraints.EAST;
        c.gridy = 1; c.ipadx = 5;
        gridbag.setConstraints(passLabel, c);
        pane.add(passLabel);

        gridbag.setConstraints(pass, c);
        pass.addActionListener(actionListener);
        pass.addKeyListener(keyListener);
        pane.add(pass);

        c.gridy = 2;
        c.gridwidth = GridBagConstraints.REMAINDER;
        c.anchor = GridBagConstraints.CENTER;
        JPanel panel = new JPanel();
        okButton.addActionListener(actionListener);
        okButton.addKeyListener(keyListener);
        panel.add(okButton);
        cancelButton.addActionListener(actionListener);
        cancelButton.addKeyListener(keyListener);
        panel.add(cancelButton);
        gridbag.setConstraints(panel, c);
        pane.add(panel);

        getContentPane().add(pane);

        pack();
    }

    /** Shows the dialog and returns true if the user pressed ok.
     */
    public boolean showDialog(){
        show();
        return pressed_OK;
    }
}

